/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.backup.util;

import java.util.List;
import org.apache.commons.lang3.StringUtils;
import org.apache.hadoop.hbase.TableName;
import org.apache.yetus.audience.InterfaceAudience;

/**
 * Backup set is a named group of HBase tables, which are managed together by Backup/Restore
 * framework. Instead of using list of tables in backup or restore operation, one can use set's name
 * instead.
 */
@InterfaceAudience.Private
public class BackupSet {
  private final String name;
  private final List<TableName> tables;

  public BackupSet(String name, List<TableName> tables) {
    this.name = name;
    this.tables = tables;
  }

  public String getName() {
    return name;
  }

  public List<TableName> getTables() {
    return tables;
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append(name).append("={");
    sb.append(StringUtils.join(tables, ','));
    sb.append("}");
    return sb.toString();
  }

}
