/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.client;

import java.util.concurrent.CompletableFuture;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.hbase.RegionLocations;
import org.apache.hadoop.hbase.ServerName;
import org.apache.hadoop.hbase.security.User;
import org.apache.yetus.audience.InterfaceAudience;

/**
 * Registry that does nothing. Otherwise, default Registry wants zookeeper up and running.
 */
@InterfaceAudience.Private
public class DoNothingConnectionRegistry implements ConnectionRegistry {

  public DoNothingConnectionRegistry(Configuration conf, User user) {
  }

  @Override
  public CompletableFuture<RegionLocations> getMetaRegionLocations() {
    return CompletableFuture.completedFuture(null);
  }

  @Override
  public CompletableFuture<String> getClusterId() {
    return CompletableFuture.completedFuture(null);
  }

  @Override
  public CompletableFuture<ServerName> getActiveMaster() {
    return CompletableFuture.completedFuture(null);
  }

  @Override
  public String getConnectionString() {
    return "nothing";
  }

  @Override
  public void close() {
  }
}
