/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.regionserver.storefiletracker;

import static org.junit.Assert.assertThrows;

import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.hbase.HBaseClassTestRule;
import org.apache.hadoop.hbase.HBaseConfiguration;
import org.apache.hadoop.hbase.regionserver.StoreContext;
import org.apache.hadoop.hbase.testclassification.RegionServerTests;
import org.apache.hadoop.hbase.testclassification.SmallTests;
import org.junit.ClassRule;
import org.junit.Test;
import org.junit.experimental.categories.Category;

@Category({ RegionServerTests.class, SmallTests.class })
public class TestStoreFileTrackerFactory {

  @ClassRule
  public static final HBaseClassTestRule CLASS_RULE =
    HBaseClassTestRule.forClass(TestStoreFileTrackerFactory.class);

  @Test
  public void testCreateForMigration() {
    Configuration conf = HBaseConfiguration.create();
    String configName = "config";

    // no config
    assertThrows(NullPointerException.class, () -> StoreFileTrackerFactory.createForMigration(conf,
      configName, false, StoreContext.getBuilder().build()));

    // class not found
    conf.set(configName, "config");
    assertThrows(RuntimeException.class, () -> StoreFileTrackerFactory.createForMigration(conf,
      configName, false, StoreContext.getBuilder().build()));

    // nested MigrationStoreFileTracker
    conf.setClass(configName, MigrationStoreFileTracker.class, StoreFileTrackerBase.class);
    assertThrows(IllegalArgumentException.class, () -> StoreFileTrackerFactory
      .createForMigration(conf, configName, false, StoreContext.getBuilder().build()));
  }
}
